==> style-o-matic-1.1.3.tgz: package/es/components/Nav/NavFolder.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import classNames from "classnames";
import { CoreComponent, getCorePropDefaults, getCorePropTypes, getValidProps, UIGlobals, ROLE } from "../../lib";

var NavFolder = (_temp = _class = function (_CoreComponent) {
  _inherits(NavFolder, _CoreComponent);

  function NavFolder(props) {
    _classCallCheck(this, NavFolder);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _initialiseProps.call(_this);

    _this.useParentNode = true;
    _this.state = {
      expanded: "",
      bottomOffset: 0,
      leftOffset: 0
    };
    return _this;
  }

  NavFolder.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        uiclass = _getValidProps.uiclass,
        className = _getValidProps.className,
        to = _getValidProps.to,
        path = _getValidProps.path,
        text = _getValidProps.text,
        icon = _getValidProps.icon,
        minimized = _getValidProps.minimized,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var expanded = this.state.expanded;


    var classes = {
      expanded: expanded,
      minimized: minimized,
      active: to && path.indexOf(to) !== -1
    };

    var offsetStyle = {
      bottom: this.state.bottomOffset + "px"
    };

    var caretClass = !minimized && expanded ? "fa fa-caret-down" : "fa fa-caret-right";

    return React.createElement(
      "div",
      {
        className: "ui-nav-flyout-wrapper",
        ref: this.onSetRef,
        onMouseEnter: this.handleMouseEnter
      },
      React.createElement(
        "a",
        { className: "ui-nav-item", href: to, label: text },
        React.createElement("i", { className: "ui-nav-item-icon " + icon }),
        React.createElement(
          "span",
          { className: "ui-nav-item-info" },
          text
        ),
        React.createElement("span", {
          className: "ui-nav-item-caret " + caretClass,
          role: "presentation",
          onKeyDown: this.toggleExpansion,
          onClick: this.toggleExpansion
        })
      ),
      React.createElement(
        Component,
        _extends({}, props, {
          className: classNames(className, classes),
          style: offsetStyle
        }),
        React.createElement(
          "div",
          { className: "ui-nav-folder-title" },
          text
        ),
        React.Children.map(children, function (child) {
          if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
            return _this2.renderChild(child, inherited);
          }
          return child;
        })
      )
    );
  };

  return NavFolder;
}(CoreComponent), _class.propTypes = getCorePropTypes({
  minimized: "bool"
}), _class.defaultProps = getCorePropDefaults({
  uirole: ROLE.FOLDER,
  text: "",
  minimized: false
}), _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.handleMouseEnter = function (e) {
    if (_this3.node) {
      var _UIGlobals$getScreenD = UIGlobals.getScreenDimensions(),
          screenBottom = _UIGlobals$getScreenD.bottom,
          screenHeight = _UIGlobals$getScreenD.height;

      var _node$getBoundingClie = _this3.node.getBoundingClientRect(),
          y = _node$getBoundingClie.y,
          height = _node$getBoundingClie.height,
          bottom = _node$getBoundingClie.bottom;

      var bottomOffset = y;
      if (y > screenHeight / 2) {
        bottomOffset = height / 2;
        bottomOffset += screenHeight;
        bottomOffset -= bottom;
      }
      _this3.setState({ bottomOffset: bottomOffset });
    }
  };

  this.toggleExpansion = function (e) {
    e.preventDefault();
    if (!_this3.props.minimized) {
      _this3.setState({ expanded: !_this3.state.expanded });
    }
  };

  this.renderChild = function (child, props) {
    var role = child.props.uirole || ROLE.ITEM;
    var ref = function ref(c) {
      _this3[role] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this3.chainFunction(child.ref, ref);
    }
    return cloneElement(child, _extends({}, props, {
      ref: ref,
      uiclass: _this3.childPrefix(role),
      onClick: _this3.chainFunction(child.props.onClick, _this3.handleOnClick)
    }));
  };
}, _temp);


export default NavFolder;

==> style-o-matic-1.1.5.tgz: package/es/components/Nav/NavFolder.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import classNames from "classnames";
import activeElement from "dom-helpers/activeElement";
import contains from "dom-helpers/query/contains";
import { CoreComponent, setCorePropDefaults, setCorePropTypes, getValidProps, UIGlobals, ROLE } from "../../lib";

var NavFolder = (_temp = _class = function (_CoreComponent) {
  _inherits(NavFolder, _CoreComponent);

  function NavFolder(props) {
    _classCallCheck(this, NavFolder);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _initialiseProps.call(_this);

    _this.folder = null;
    _this.useParentNode = true;
    _this.state = {
      open: false,
      offset: {}
    };
    return _this;
  }

  NavFolder.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        uiclass = _getValidProps.uiclass,
        className = _getValidProps.className,
        to = _getValidProps.to,
        path = _getValidProps.path,
        text = _getValidProps.text,
        icon = _getValidProps.icon,
        visible = _getValidProps.visible,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var _state = this.state,
        offset = _state.offset,
        open = _state.open;


    var classes = {
      open: open,
      active: to && path.indexOf(to) !== -1
    };

    var caretClass = open ? "ui-icon-remove" : "ui-icon-add";
    var itemClass = visible ? "ui-nav-item visible" : "ui-nav-item";

    return React.createElement(
      "div",
      {
        className: itemClass,
        ref: this.onSetRef,
        role: "presentation",
        onKeyDown: this.toggleExpansion,
        onClick: this.toggleExpansion
      },
      React.createElement(
        "a",
        { className: "ui-nav-item-link", href: to, label: text },
        React.createElement("i", { className: "ui-nav-item-icon " + caretClass }),
        React.createElement(
          "span",
          { className: "ui-nav-item-info" },
          text
        )
      ),
      React.createElement(
        Component,
        _extends({}, props, {
          className: classNames(className, classes),
          style: offset,
          ref: this.setFolderRef
        }),
        React.createElement(
          "div",
          { className: "ui-nav-folder-title" },
          text
        ),
        React.Children.map(children, function (child) {
          if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === ROLE.ITEM) {
            return _this2.renderChild(child, inherited);
          }
          return child;
        })
      )
    );
  };

  return NavFolder;
}(CoreComponent), _class.propTypes = setCorePropTypes({
  minimized: "bool"
}), _class.defaultProps = setCorePropDefaults({
  uirole: ROLE.FOLDER,
  text: ""
}), _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.setFolderRef = function (ref) {
    if (ref) {
      var needsUpdate = _this3.folder === null;
      _this3.folder = ref;
      if (needsUpdate) {
        _this3.forceUpdate();
      }
    }
  };

  this.toggleExpansion = function (e) {
    e.preventDefault();
    var newState = _this3.state;
    if (!newState.open && _this3.node && _this3.folder) {
      var _UIGlobals$getScreenD = UIGlobals.getScreenDimensions(),
          screenBottom = _UIGlobals$getScreenD.bottom,
          screenHeight = _UIGlobals$getScreenD.height,
          screenWidth = _UIGlobals$getScreenD.width;

      var _node$getBoundingClie = _this3.node.getBoundingClientRect(),
          x = _node$getBoundingClie.x,
          y = _node$getBoundingClie.y,
          height = _node$getBoundingClie.height,
          bottom = _node$getBoundingClie.bottom;

      var _folder$getBoundingCl = _this3.folder.getBoundingClientRect(),
          folderWidth = _folder$getBoundingCl.width;

      var offset = {};
      if (y > screenHeight / 2) {
        var bottomOffset = 0;
        bottomOffset = height;
        bottomOffset += screenHeight;
        bottomOffset -= bottom;
        offset.bottom = bottomOffset + "px";
      }
      if (x + folderWidth > screenWidth - 10) {
        offset.right = "10px";
      }
      newState.offset = offset;
    }
    newState.open = !newState.open;
    _this3.setState(newState);
  };

  this.renderChild = function (child, props) {
    var role = child.props.uirole || ROLE.ITEM;
    var ref = function ref(c) {
      _this3[role] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this3.chainFunction(child.ref, ref);
    }
    return cloneElement(child, _extends({}, props, {
      ref: ref,
      uirole: ROLE.FOLDERITEM,
      uiclass: _this3.childPrefix(role),
      onClick: _this3.chainFunction(child.props.onClick, _this3.handleOnClick)
    }));
  };
}, _temp);


export default NavFolder;
